@@ -1,19 +1,19 @@
 
 /*
- * Copyright (C) 2006 Juan Pablo Ugarte.
+ * Copyright (C) 2006-2016 Juan Pablo Ugarte.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * Authors:
@@ -232,7 +232,6 @@ glade_base_editor_get_type_info (GladeBaseEditor *e,
   return FALSE;
 }
 
-
 static gchar *
 glade_base_editor_get_display_name (GladeBaseEditor *editor,
                                     GladeWidget     *gchild)
@@ -241,6 +240,7 @@ glade_base_editor_get_display_name (GladeBaseEditor *editor,
   g_signal_emit (editor,
                  glade_base_editor_signals[SIGNAL_GET_DISPLAY_NAME],
                  0, gchild, &retval);
+
   return retval;
 }
 
@@ -350,15 +350,30 @@ glade_base_editor_name_activate (GtkEntry *entry, GladeWidget *gchild)
 {
   const gchar *text = gtk_entry_get_text (GTK_ENTRY (entry));
   GladeBaseEditor *editor = g_object_get_data (G_OBJECT (entry), "editor");
+  gchar *new_name = NULL;
 
-  if (text && text[0] && strcmp (glade_widget_get_name (gchild), text))
+  if (text == NULL || text[0] == '\0')
     {
-      g_signal_handlers_block_by_func (glade_widget_get_project (gchild),
+      /* If we are explicitly trying to set the widget name to be empty,
+       * then we must not allow it there are any active references to
+       * the widget which would otherwise break.
+       */
+      if (!glade_widget_has_prop_refs (gchild))
+	new_name = glade_project_new_widget_name (editor->priv->project, NULL, GLADE_UNNAMED_PREFIX);
+    }
+  else
+    new_name = g_strdup (text);
+
+  if (new_name && new_name[0])
+    {
+      g_signal_handlers_block_by_func (editor->priv->project,
                                        glade_base_editor_project_widget_name_changed, editor);
-      glade_command_set_name (gchild, text);
-      g_signal_handlers_unblock_by_func (glade_widget_get_project (gchild),
+      glade_command_set_name (gchild, new_name);
+      g_signal_handlers_unblock_by_func (editor->priv->project,
                                          glade_base_editor_project_widget_name_changed, editor);
     }
+
+  g_free (new_name);
 }
 
 static void
@@ -1422,7 +1437,7 @@ static gchar *
 glade_base_editor_get_display_name_impl (GladeBaseEditor *editor,
                                          GladeWidget     *gchild)
 {
-  return g_strdup (glade_widget_get_name (gchild));
+  return g_strdup (glade_widget_get_display_name (gchild));
 }
 
 static GladeWidget *
@@ -2016,12 +2031,16 @@ glade_base_editor_add_default_properties (GladeBaseEditor *editor,
       get_children_model_for_child_type (editor, G_OBJECT_TYPE (child));
 
   /* Name */
-  label = gtk_label_new (_("Name:"));
+  label = gtk_label_new (_("ID:"));
   gtk_widget_set_halign (label, GTK_ALIGN_END);
   gtk_widget_set_valign (label, GTK_ALIGN_START);
 
   entry = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (entry), glade_widget_get_name (gchild));
+  if (glade_widget_has_name (gchild))
+    gtk_entry_set_text (GTK_ENTRY (entry), glade_widget_get_name (gchild));
+  else
+    gtk_entry_set_text (GTK_ENTRY (entry), "");
+
   g_object_set_data (G_OBJECT (entry), "editor", editor);
   g_signal_connect (entry, "activate",
                     G_CALLBACK (glade_base_editor_name_activate), gchild);
@@ -2229,9 +2248,10 @@ glade_base_editor_pack_new_window (GladeBaseEditor *editor,
 
   if (title)
     {
-      real_title = g_strdup_printf ("%s - %s", title,
-                                    glade_widget_get_name (editor->priv->
-                                                           gcontainer));
+      const gchar *widget_name =
+	glade_widget_get_display_name (editor->priv->gcontainer);
+
+      real_title = g_strdup_printf ("%s - %s", title, widget_name);
       gtk_window_set_title (GTK_WINDOW (window), real_title);
       g_free (real_title);
     }
