@@ -827,8 +827,7 @@ glade_eprop_column_types_create_input (GladeEditorProperty * eprop)
   label = gtk_label_new (string);
   g_free (string);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-  gtk_misc_set_padding (GTK_MISC (label), 2, 4);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
 
   swin = gtk_scrolled_window_new (NULL, NULL);
