@@ -140,6 +140,41 @@ glade_gtk_action_widgets_write_responses (GladeWidget *widget,
   g_list_free (action_widgets);
 }
 
+void
+glade_gtk_action_widgets_ensure_names (GladeWidget *widget, gchar *action_container)
+{
+  GList *l, *action_widgets;
+  GladeWidget *action_area;
+
+  if ((action_area = glade_gtk_action_widgets_get_area (widget, action_container)) == NULL)
+   {
+     g_warning ("%s: Could not find action widgets container [%s]", __func__, action_container);
+     return;
+   }
+
+  action_widgets = glade_widget_get_children (action_area);
+
+  for (l = action_widgets; l; l = l->next)
+    {
+      GladeWidget *action_widget;
+      GladeProperty *property;
+
+      if ((action_widget = glade_widget_get_from_gobject (l->data)) == NULL)
+        continue;
+
+      if ((property =
+           glade_widget_get_property (action_widget, "response-id")) == NULL)
+        continue;
+
+      if (!glade_property_get_enabled (property))
+	continue;
+
+      glade_widget_ensure_name (action_widget, glade_widget_get_project (action_widget), FALSE);
+    }
+
+  g_list_free (action_widgets);
+}
+
 void
 glade_gtk_action_widgets_write_child (GladeWidget *widget,
                                       GladeXmlContext *context,
